@@ -7,6 +7,11 @@
 # Sunburst
 
 from global_chem_extensions.sunburster.sunburster import Sunburster
+
+# PCA Analysis
+
+from global_chem_extensions.node_pca_analysis.node_pca_analysis import PCAAnalysis
+
 # Base Package
 
 from global_chem_extensions.global_chem_extensions import GlobalChemExtensions
